#
# spec file for package viddy
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           viddy
Version:        1.3.0
Release:        1.3
Summary:        A modern watch command
License:        MIT
Group:          System/Monitoring
URL:            https://github.com/sachaos/viddy
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
ExclusiveArch:  %{rust_tier1_arches}

%description
Modern watch command.
Features:
* Basic features of original watch command:
  + Execute command periodically, and display the result.
  + color output.
  + diff highlight.
* Time machine mode:
  + Rewind like video.
  + Go to the past, and back to the future.
* See output in pager.
* Vim like keymaps.
* Search text.
* Suspend and restart execution.
* Run command in precise intervals forcibly.
* Support shell alias
* Customize keymappings.
* Customize color.

%prep
%autosetup -a 1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/viddy

%changelog
* Tue Dec  3 2024 mardnh@gmx.de
- Update to version 1.3.0:
  * Update to v1.3.0
  * Fix clippy error
  * Update dependencies
  * Fix fmt
  * Add option to disable mouse capture
* Sun Nov 17 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1:
  * Update dependencies
* Sat Nov  9 2024 mardnh@gmx.de
- Update to version 1.2.0:
  * Update to v1.2.0
  * Support configuring pager keybindings.
  * Update README
  * Update to v1.1.6
  * Fix panic on executing command directly.
  * Update to v1.1.5 to fix version conflict
* Sun Sep 29 2024 mardnh@gmx.de
- Update to version 1.1.4:
  * Update to v1.1.4
  * chore: fix version to match with the release.
  * fix: drop append -c in app.rs as it's already added in
    prepare_command.
  * Revert "fix: ensure prepare_command only appends one
  - c arguemnt to shell"
  * fix: ensure prepare_command only appends one -c arguemnt
    to shell.
  * Update to v1.1.2
  * Bump gix-path from 0.10.9 to 0.10.10
  * Update version to v1.1.1
  * Support pagedown and pageup
  * Update Cargo.lock
  * Update README.md
  * Update to 1.1.0
  * Minimum interval validation
  * Support scrolling by mouse
  * Add license at Cargo.toml
  * Update README.md
  * Update version to v1.0.2
  * feat: Remove lazy_static dependency and use LazyLock instead.
* Sat Aug 24 2024 mardnh@gmx.de
- Update to version 1.0.1:
  * fix: many typos
  * Update demo
  * Update README.md
  * Change version to v1.0.0
  * Remove unnecessary debug message
  * Add help about move right and left
  * Remove intersperse
  * Update demo image
  * Update RC version
  * Skip strip arm musl binary
  * Remove gnu binary and update README
  * Build musl binaries
  * Support ansicode and char width for tab
  * normalize_stdout: reset alignment on new lines
  * Update README
  * Handle reset code
  * normalize_stdout: maintain the elasticity of tabs
  * Support arrow key in pager
  * Support tab
  * Add rc.2 install guide for linux
  * Update README about lookback feature
  * Implement save & lookback feature
  * Move MemoryStore to memory.rs
  * Add Store trait
  * Rename to MemoryStoreData
  * Fix shell option message for Windows
  * Enable to set some styles
  * Update README
  * Add tag target
  * Remove go description
  * Remove go files and add rust files
  * README: Document the option for skipping empty diffs
  * check if using powershell in windows
  * Minor README.md improvements
* Sun Apr  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Enable tests
* Sun Oct 15 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.0:
  * Add --no-shell option
  * Do not execute command when suspended
  * Fix bug of switching time machine
* Tue Aug 29 2023 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.3.7
